@@ -77,6 +77,9 @@ FAILEDOPERATION_PROTOCOLCHECKERR = 'FailedOperation.ProtocolCheckErr'
 # 收件人已退订。
 FAILEDOPERATION_RECEIVERHASUNSUBSCRIBED = 'FailedOperation.ReceiverHasUnsubscribed'
 
+# 邮件被收信人拒绝。
+FAILEDOPERATION_REJECTEDBYRECIPIENTS = 'FailedOperation.RejectedByRecipients'
+
 # 您的发送遇到问题，请联系腾讯云提交工单沟通原因并解决。
 FAILEDOPERATION_SENDEMAILERR = 'FailedOperation.SendEmailErr'
 
@@ -131,6 +134,12 @@ INVALIDPARAMETERVALUE_EMAILCONTENTISWRONG = 'InvalidParameterValue.EmailContentI
 # 邮件地址不合法，请检查邮件地址格式。
 INVALIDPARAMETERVALUE_ILLEGALEMAILADDRESS = 'InvalidParameterValue.IllegalEmailAddress'
 
+# 发信人别名错误。
+INVALIDPARAMETERVALUE_ILLEGALSENDERNAME = 'InvalidParameterValue.IllegalSenderName'
+
+# 收件人地址附带的模板参数不能包含html标签。
+INVALIDPARAMETERVALUE_INVALIDTEMPLATEDATA = 'InvalidParameterValue.InValidTemplateData'
+
 # 域名取值错误。
 INVALIDPARAMETERVALUE_INVALIDEMAILIDENTITY = 'InvalidParameterValue.InvalidEmailIdentity'
 
@@ -143,6 +152,9 @@ INVALIDPARAMETERVALUE_NOTEXISTDOMAIN = 'InvalidParameterValue.NotExistDomain'
 # 收件人列表描述不合法，描述不可包含特殊字符，字符长度范围:1~300。
 INVALIDPARAMETERVALUE_RECEIVERDESCILLEGAL = 'InvalidParameterValue.ReceiverDescIllegal'
 
+# 收件人地址错误。
+INVALIDPARAMETERVALUE_RECEIVEREMAILINVALID = 'InvalidParameterValue.ReceiverEmailInvalid'
+
 # 收件人列表名字不合法，请检查字符内容及大小。
 INVALIDPARAMETERVALUE_RECEIVERNAMEILLEGAL = 'InvalidParameterValue.ReceiverNameIllegal'
 
@@ -164,9 +176,15 @@ INVALIDPARAMETERVALUE_TEMPLATECONTENTISNULL = 'InvalidParameterValue.TemplateCon
 # 模板内容错误，请检查base64内容是否正确。
 INVALIDPARAMETERVALUE_TEMPLATECONTENTISWRONG = 'InvalidParameterValue.TemplateContentIsWrong'
 
-# 变量设置必须为json格式。
+# 模板参数必须为json格式。
 INVALIDPARAMETERVALUE_TEMPLATEDATAERROR = 'InvalidParameterValue.TemplateDataError'
 
+# 模板参数变量名与之前不一致。
+INVALIDPARAMETERVALUE_TEMPLATEDATAINCONSISTENT = 'InvalidParameterValue.TemplateDataInconsistent'
+
+# 单条收件人地址附带的模板参数(整个 JSON 结构)， 长度超过限制 800 bytes
+INVALIDPARAMETERVALUE_TEMPLATEDATALENLIMIT = 'InvalidParameterValue.TemplateDataLenLimit'
+
 # 模板名字不合法，请检查字符内容及大小。
 INVALIDPARAMETERVALUE_TEMPLATENAMEILLEGAL = 'InvalidParameterValue.TemplateNameIllegal'
 
@@ -185,12 +203,15 @@ INVALIDPARAMETERVALUE_WRONGDATE = 'InvalidParameterValue.WrongDate'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
-# 收件人地址数量超过限制。
-LIMITEXCEEDED_EXCEEDRECEIVERDETAILLIMIT = 'LimitExceeded.ExceedReceiverDetailLimit'
-
 # 收件人列表数量超过限制。
 LIMITEXCEEDED_EXCEEDRECEIVERLIMIT = 'LimitExceeded.ExceedReceiverLimit'
 
+# 该收件人列表包含的收件人地址总量超过限制。
+LIMITEXCEEDED_RECEIVERDETAILCOUNTLIMIT = 'LimitExceeded.ReceiverDetailCountLimit'
+
+# 请求的收件人地址数量超过限制。
+LIMITEXCEEDED_RECEIVERDETAILREQUESTLIMIT = 'LimitExceeded.ReceiverDetailRequestLimit'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -221,7 +242,7 @@ OPERATIONDENIED_EXCEEDDOMAINLIMIT = 'OperationDenied.ExceedDomainLimit'
 # 超出最大发信地址限制。
 OPERATIONDENIED_EXCEEDSENDERLIMIT = 'OperationDenied.ExceedSenderLimit'
 
-# 收件人列表正在被操作，请稍后操作。
+# 收件人列表正在上传中，请稍后操作。
 OPERATIONDENIED_RECEIVERISOPERATING = 'OperationDenied.ReceiverIsOperating'
 
 # 收件人列表不存在。
